#include <IRremote.h> // Knihovna pro IR přijímač
#define RECV_PIN 12   // Výstup IR senzoru je připojen k pinu 12

IRrecv irrecv(RECV_PIN); // Objekt IRrecv připojený k pinu RECV_PIN
decode_results results; // Objekt decode_results pro ukládání výsledků

#define IN1 9 // Připojení výstupních pinů ke vstupům driveru
#define IN2 8
#define IN3 7
#define IN4 6
#define ENA 10 // Pin pro aktivaci motoru A
#define ENB 5  // Pin pro aktivaci motoru B

#define IR_FORWARD    0x00ff629d    // Definice kódu z IR ovladače
#define IR_BACK    0x00ffa857       // Přepsáním lze nastavit i na jiná tlačítka, případně jiný ovladač
#define IR_LEFT    0x00ff22dd
#define IR_RIGHT   0x00ffc23d
#define IR_STOP    0x00ff02fd

int speed = 200; // proměnná pro rychlost, hodnoty od 0 do 255

void setup(){ 
    pinMode(IN1, OUTPUT); // Nastaví piny pro ovládání driveru jako výstupy
    pinMode(IN2, OUTPUT);
    pinMode(IN3, OUTPUT);
    pinMode(IN4, OUTPUT);
    pinMode(ENA, OUTPUT);
    pinMode(ENB, OUTPUT);

    irrecv.enableIRIn(); // Začne přijímat IR signály
}

void loop(){  
    unsigned long key;    // Proměnná pro uchování přijatých dat
    if(irrecv.decode(&results)){ // Pokud je přijat IR signál
        key = results.value; // Zápis hodnoty přijatého signálu do proměnné key
        switch(key){
            case IR_FORWARD: // Pokud se hodnota shoduje s definovaným IR_FORWARD
                forward();   // Jede vpřed
                break;       // Ukončí case
            case IR_BACK: // Pokud se hodnota shoduje s definovaným IR_BACK
                back();   // Jede dozadu
                break;
            case IR_LEFT: // Pokud se hodnota shoduje s definovaným IR_LEFT
                left();   // Zatočí doleva
                break;
            case IR_RIGHT: // Pokud se hodnota shoduje s definovaným IR_RIGHT
                right();   // Zatočí doprava
                break;
            case IR_STOP: // Pokud se hodnota shoduje s definovaným IR_STOP
                stop();   // Zastaví robota
                break;
        } 
        irrecv.resume(); // Začne opět přijímat signály
    }
}

void forward(){ // Funkce pro jízdu dopředu
    digitalWrite(IN1, LOW);
    digitalWrite(IN2, HIGH);
    digitalWrite(IN3, LOW);
    digitalWrite(IN4, HIGH);
    analogWrite(ENA, speed);
    analogWrite(ENB, speed);
}

void back(){ // Funkce pro jízdu dozadu
    digitalWrite(IN1, HIGH);
    digitalWrite(IN2, LOW);
    digitalWrite(IN3, HIGH);
    digitalWrite(IN4, LOW);
    analogWrite(ENA, speed);
    analogWrite(ENB, speed);
}

void left(){ // Funkce pro zatáčení doleva
    digitalWrite(IN1, LOW);
    digitalWrite(IN2, HIGH);
    digitalWrite(IN3, HIGH);
    digitalWrite(IN4, LOW);
    analogWrite(ENA, speed);
    analogWrite(ENB, speed);
}

void right(){ // Funkce pro zatáčení doprava
    digitalWrite(IN1, HIGH);
    digitalWrite(IN2, LOW);
    digitalWrite(IN3, LOW);
    digitalWrite(IN4, HIGH);
    analogWrite(ENA, speed);
    analogWrite(ENB, speed);
}

void stop(){ // Funkce pro zastavení robota
  digitalWrite(ENA, LOW);
  digitalWrite(ENB, LOW);
}
